@@ -18,14 +18,14 @@ G_BEGIN_DECLS
 #undef GDK_WINDOWING_MACOS
 
 #ifndef GENTOO_GTK_HIDE_WAYLAND
-#undef GDK_WINDOWING_WAYLAND
+#define GDK_WINDOWING_WAYLAND
 #endif
 
 #undef GDK_WINDOWING_WIN32
 
 #define GDK_RENDERING_CAIRO
 #define GDK_RENDERING_GL
-#undef GDK_RENDERING_VULKAN
+#define GDK_RENDERING_VULKAN
 
 G_END_DECLS
 
